import os


def find_meta_file(gml_file: str = None) -> str | None:
    """
    Returns a meta_file file path for a given gml file. Usually a .xsd or .gfs file
    :param gml_file: file path for gml file
    :return: meta_file: file path to meta file or None if not found
    """

    dirname = os.path.dirname(gml_file)
    basename = os.path.basename(gml_file)
    basename_no_ext = os.path.splitext(basename)[0]

    files_temp = [filename for filename in os.listdir(dirname) if filename.lower().startswith(basename_no_ext.lower()) and filename != basename]
    if files_temp:
        meta_file = os.path.join(dirname, files_temp[0])
    else:
        meta_file = None

    return meta_file



import os
from clean_gml.gml import Gml

filepath = 'examples/Blinde_inlaten copy.gml'
filepath = 'example.gml'

datatype_changes = {'OPENBARE_RUIMTE': 'xsd:float'}
datatype_changes = {'PROPERTY': 'xsd:float'}

gml = Gml(filepath)
gml.datatype_changes(changes=datatype_changes)
gml.replace_commas(ndigits=3)
gml.save()



import yaml


def yml2dict(file):
    """
    Open yaml file and return as dict

    input:
    file --  the yaml input file

    output:
    dic -- the content of the yaml file as a python dictionary
    """

    with open(file, 'r') as f:
        # The FullLoader parameter handles the conversion from YAML scalar values to Python the dictionary format
        dic = yaml.load(f, Loader=yaml.FullLoader)

    return dic


from setuptools import setup, find_namespace_packages


with open('README.md', 'r') as f:
    long_description = f.read()

setup(
    name='GML cleaner',
    license='MIT',
    license_files='LICENSE.txt',
    description='Gml cleaner is a python library for manupulating data and meta data in gml files.',
    long_description=long_description,
    long_description_content_type='text/markdown',
    version='1.1',
    url='https://github.com/infralytics/gml_cleaner',
    author='Wouter van Riel',
    author_email='wouter.van.riel@infralytics.org',
    packages=find_namespace_packages(),
    install_requires=['setuptools'],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.10',
        'Topic :: Scientific/Engineering :: GIS',
        'Topic :: Text Processing :: Markup :: XML'
        ]
    )



import os
import re
import xml.etree.ElementTree as ET
from xml.dom import minidom
from clean_gml.namespace import namespaces
from clean_gml.utils import get_file_split
from clean_gml.find_meta import find_meta_file


class GmlBase:

    def __init__(self, file):
        self.file = file
        self.root = self.parse()

    def parse(self):
        mytree = ET.parse(self.file)
        myroot = mytree.getroot()
        for prefix, namespace in namespaces.items():
            ET.register_namespace(prefix, namespace)
        return myroot

    def prepare_save_path(self):
        new_dir = 'adjusted'

        base_dir = os.path.dirname(self.file)
        try:
            os.mkdir(os.path.join(base_dir, new_dir))
        except Exception:
            pass

        basename = os.path.basename(self.file)

        return os.path.join(base_dir, new_dir, basename)

    def _save_xml(self):

        _, _, extension = get_file_split(self.file)

        xmlstr = minidom.parseString(ET.tostring(self.root)).toprettyxml()

        if extension == '.gfs':
            xmlstr = xmlstr.replace('<?xml version="1.0" ?>', '')
            xmlstr = re.sub('^\s*\n', '', xmlstr)

        filename = self.prepare_save_path()

        with open(filename, "w") as f:
            f.write(xmlstr)
